pub struct Memory {
pub socket_recv_buffer_size: usize,
pub socket_send_buffer_size: usize,
pub buffer_pool_size: usize,
pub buffer_pool_count: usize,
pub capture_pool_size: usize,
pub capture_pool_count: usize,
}Expand description
Memory configuration for transport and buffer pools
Fields
socket_recv_buffer_size: usizeTCP socket receive buffer size for backend and client connections
socket_send_buffer_size: usizeTCP socket send buffer size for backend and client connections
buffer_pool_size: usizeSize of each pooled I/O buffer used for streaming
buffer_pool_count: usizeNumber of buffers in the main buffer pool
capture_pool_size: usizeSize of each capture buffer for caching and response assembly
capture_pool_count: usizeNumber of buffers in the capture pool