Module buffer

Module buffer 

Structs

BufferPool
Lock-free buffer pool for reusing large I/O buffers.
ChunkedResponse
Buffered response assembled from one or more pooled capture buffers.
HotPathAllocationMetricsSnapshot
Snapshot of allocation-sensitive hot-path activity.
PooledBuffer
A pooled buffer that automatically returns to the pool when dropped
ResponseWriteMetricsSnapshot
Snapshot of direct client write-path activity from ChunkedResponse::write_all_to.

Functions

hot_path_allocation_metrics_snapshot
reset_hot_path_allocation_metrics
response_write_metrics_snapshot