pub struct BackendCount(/* private fields */);Expand description
Number of backend servers in the router.
Implementations
Sourceimpl BackendCount
impl BackendCount
Sourcepub const MAX: usize = BackendId::MAX_COUNT
pub const MAX: usize = BackendId::MAX_COUNT
Maximum backend count that fits the article availability bitmap.
Sourcepub const fn try_new(count: usize) -> Option<Self>
pub const fn try_new(count: usize) -> Option<Self>
Construct a bounded backend count from a raw length.
Sourcepub fn backend_ids(self) -> impl ExactSizeIterator<Item = BackendId>
pub fn backend_ids(self) -> impl ExactSizeIterator<Item = BackendId>
Iterate every valid backend ID in this bounded count.