pub struct ConnectionStream { /* private fields */ }Expand description
Unified stream type that can represent different connection types.
The stream also owns pending backend input that was already consumed from the socket but belongs to the next NNTP response.
Implementations
Sourceimpl ConnectionStream
impl ConnectionStream
Sourcepub fn compressed_plain(stream: TcpStream) -> Self
pub fn compressed_plain(stream: TcpStream) -> Self
Create a compressed plain TCP connection stream
Sourcepub fn compressed_tls(stream: TlsStream<TcpStream>) -> Self
pub fn compressed_tls(stream: TlsStream<TcpStream>) -> Self
Create a compressed TLS connection stream
Sourcepub const fn connection_type(&self) -> &'static str
pub const fn connection_type(&self) -> &'static str
Returns the connection type as a string for logging/debugging
Sourcepub const fn is_encrypted(&self) -> bool
pub const fn is_encrypted(&self) -> bool
Returns true if this connection uses encryption (TLS/SSL)
Sourcepub const fn is_unencrypted(&self) -> bool
pub const fn is_unencrypted(&self) -> bool
Returns true if this connection is unencrypted (plain TCP)
Sourcepub const fn is_compressed(&self) -> bool
pub const fn is_compressed(&self) -> bool
Returns true if this connection uses wire compression
Sourcepub const fn as_tcp_stream(&self) -> Option<&TcpStream>
pub const fn as_tcp_stream(&self) -> Option<&TcpStream>
Get a reference to the underlying TCP stream (if plain, uncompressed TCP)
Returns None for TLS or compressed streams. Useful for socket optimization that requires direct TCP access.
Sourcepub const fn as_tcp_stream_mut(&mut self) -> Option<&mut TcpStream>
pub const fn as_tcp_stream_mut(&mut self) -> Option<&mut TcpStream>
Get a mutable reference to the underlying TCP stream (if plain, uncompressed TCP)
Sourcepub fn as_tls_stream(&self) -> Option<&TlsStream<TcpStream>>
pub fn as_tls_stream(&self) -> Option<&TlsStream<TcpStream>>
Get a reference to the TLS stream (if uncompressed TLS connection)
Sourcepub fn as_tls_stream_mut(&mut self) -> Option<&mut TlsStream<TcpStream>>
pub fn as_tls_stream_mut(&mut self) -> Option<&mut TlsStream<TcpStream>>
Get a mutable reference to the TLS stream (if uncompressed TLS connection)
Sourcepub fn underlying_tcp_stream(&self) -> &TcpStream
pub fn underlying_tcp_stream(&self) -> &TcpStream
Get the underlying TCP stream reference regardless of connection type
For plain TCP, returns the stream directly. For TLS, returns the underlying TCP stream within the TLS wrapper. For compressed streams, returns the TCP stream from within the wrapper.
Sourcepub fn queue_pending_bytes(&mut self, bytes: &[u8]) -> Result<()>
pub fn queue_pending_bytes(&mut self, bytes: &[u8]) -> Result<()>
Queue bytes that were already read from the backend for the next response read.
Sourcepub fn queue_pending_bytes_first(&mut self, bytes: &[u8]) -> Result<()>
pub fn queue_pending_bytes_first(&mut self, bytes: &[u8]) -> Result<()>
Queue bytes ahead of any bytes already retained by this connection.
pub fn has_pending_bytes(&self) -> bool
pub fn pending_bytes_len(&self) -> usize
pub fn clear_pending_bytes(&mut self)