AsyncStream

Trait AsyncStream 

pub trait AsyncStream:
    AsyncRead
    + AsyncWrite
    + Unpin
    + Send { }
Trait for async streams that can be used for NNTP connections

This trait is automatically implemented for any type that implements AsyncRead + AsyncWrite + Unpin + Send, making it easy to support different connection types (TCP, TLS, etc.).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AsyncStream for T
where T: AsyncRead + AsyncWrite + Unpin + Send,