pub struct ClientAddress(/* private fields */);Expand description
A validated client socket address.
This newtype wrapper provides type safety and prevents mixing up client addresses with other socket addresses in the codebase.
Examples
use std::net::SocketAddr;
use nntp_proxy::types::ClientAddress;
let addr: SocketAddr = "127.0.0.1:8119".parse().unwrap();
let client_addr = ClientAddress::from(addr);
println!("Client connected from: {}", client_addr);Implementations
Sourceimpl ClientAddress
impl ClientAddress
Sourcepub const fn new(addr: SocketAddr) -> Self
pub const fn new(addr: SocketAddr) -> Self
Create a new client address from a socket address.
Examples
use std::net::SocketAddr;
use nntp_proxy::types::ClientAddress;
let addr: SocketAddr = "192.168.1.100:12345".parse().unwrap();
let client_addr = ClientAddress::new(addr);Sourcepub const fn as_socket_addr(&self) -> &SocketAddr
pub const fn as_socket_addr(&self) -> &SocketAddr
Get the underlying socket address.
Examples
use std::net::SocketAddr;
use nntp_proxy::types::ClientAddress;
let addr: SocketAddr = "10.0.0.5:9999".parse().unwrap();
let client_addr = ClientAddress::from(addr);
assert_eq!(client_addr.as_socket_addr(), &addr);Sourcepub const fn into_inner(self) -> SocketAddr
pub const fn into_inner(self) -> SocketAddr
Convert into the underlying socket address.
Examples
use std::net::SocketAddr;
use nntp_proxy::types::ClientAddress;
let addr: SocketAddr = "172.16.0.1:5555".parse().unwrap();
let client_addr = ClientAddress::from(addr);
let socket_addr = client_addr.into_inner();
assert_eq!(socket_addr, addr);Sourcepub const fn is_ipv4(&self) -> bool
pub const fn is_ipv4(&self) -> bool
Check if this is an IPv4 address.
Examples
use nntp_proxy::types::ClientAddress;
use std::net::SocketAddr;
let addr = ClientAddress::from("127.0.0.1:8119".parse::<SocketAddr>().unwrap());
assert!(addr.is_ipv4());
let addr6 = ClientAddress::from("[::1]:8119".parse::<SocketAddr>().unwrap());
assert!(!addr6.is_ipv4());Sourcepub const fn is_ipv6(&self) -> bool
pub const fn is_ipv6(&self) -> bool
Check if this is an IPv6 address.
Examples
use nntp_proxy::types::ClientAddress;
use std::net::SocketAddr;
let addr = ClientAddress::from("[::1]:8119".parse::<SocketAddr>().unwrap());
assert!(addr.is_ipv6());
let addr4 = ClientAddress::from("127.0.0.1:8119".parse::<SocketAddr>().unwrap());
assert!(!addr4.is_ipv6());Methods from Deref<Target = SocketAddr>
1.7.0 · Sourcepub fn ip(&self) -> IpAddr
pub fn ip(&self) -> IpAddr
Returns the IP address associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)));1.0.0 · Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the port number associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.port(), 8080);1.16.0 · Sourcepub fn is_ipv4(&self) -> bool
pub fn is_ipv4(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv4 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), true);
assert_eq!(socket.is_ipv6(), false);1.16.0 · Sourcepub fn is_ipv6(&self) -> bool
pub fn is_ipv6(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv6 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv6Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 65535, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), false);
assert_eq!(socket.is_ipv6(), true);Trait Implementations
Sourceimpl AsRef<SocketAddr> for ClientAddress
impl AsRef<SocketAddr> for ClientAddress
Sourcefn as_ref(&self) -> &SocketAddr
fn as_ref(&self) -> &SocketAddr
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for ClientAddress
impl Clone for ClientAddress
Sourcefn clone(&self) -> ClientAddress
fn clone(&self) -> ClientAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ClientAddress
Sourceimpl Debug for ClientAddress
impl Debug for ClientAddress
Sourceimpl Deref for ClientAddress
impl Deref for ClientAddress
Sourceimpl Display for ClientAddress
impl Display for ClientAddress
impl Eq for ClientAddress
Sourceimpl From<ClientAddress> for SocketAddr
impl From<ClientAddress> for SocketAddr
Sourcefn from(value: ClientAddress) -> Self
fn from(value: ClientAddress) -> Self
Converts to this type from the input type.
Sourceimpl From<SocketAddr> for ClientAddress
impl From<SocketAddr> for ClientAddress
Sourcefn from(value: SocketAddr) -> Self
fn from(value: SocketAddr) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ClientAddress
impl Hash for ClientAddress
Sourceimpl PartialEq for ClientAddress
impl PartialEq for ClientAddress
impl StructuralPartialEq for ClientAddress