pub struct Server {
pub host: HostName,
pub port: Port,
pub name: ServerName,
pub username: Option<String>,
pub password: Option<String>,
pub max_connections: MaxConnections,
pub use_tls: bool,
pub tls_verify_cert: bool,
pub tls_cert_path: Option<String>,
pub connection_keepalive: Option<Duration>,
pub health_check_max_per_cycle: usize,
pub health_check_pool_timeout: Duration,
}Expand description
Configuration for a single backend server
Fields
host: HostNameport: Portname: ServerNameusername: Option<String>password: Option<String>max_connections: MaxConnectionsMaximum number of concurrent connections to this server
use_tls: boolEnable TLS/SSL for this backend connection
tls_verify_cert: boolVerify TLS certificates (recommended for production)
tls_cert_path: Option<String>Optional path to custom CA certificate
connection_keepalive: Option<Duration>Interval to send keep-alive commands (DATE) on idle connections None disables keep-alive (default)
health_check_max_per_cycle: usizeMaximum number of connections to check per health check cycle Lower values reduce pool contention but may take longer to detect all stale connections
health_check_pool_timeout: DurationTimeout when acquiring a connection for health checking Short timeout prevents blocking if pool is busy
Implementations