DeadpoolConnectionProvider

Struct DeadpoolConnectionProvider 

pub struct DeadpoolConnectionProvider {
    pub health_check_metrics: Arc<Mutex<HealthCheckMetrics>>,
    /* private fields */
}
Connection provider using deadpool for connection pooling

Fields

health_check_metrics: Arc<Mutex<HealthCheckMetrics>>

Metrics for health check operations

Implementations

Source

impl DeadpoolConnectionProvider

pub fn builder( host: impl Into<String>, port: u16, ) -> DeadpoolConnectionProviderBuilder

Create a builder for constructing a connection provider

Examples
use nntp_proxy::pool::DeadpoolConnectionProvider;

let provider = DeadpoolConnectionProvider::builder("news.example.com", 119)
    .name("Example")
    .max_connections(15)
    .build()
    .unwrap();
pub fn new( host: String, port: u16, name: String, max_size: usize, username: Option<String>, password: Option<String>, ) -> Self

Create a new connection provider

pub fn new_with_tls( host: String, port: u16, name: String, max_size: usize, username: Option<String>, password: Option<String>, tls_config: TlsConfig, ) -> Result<Self>

Create a new connection provider with TLS support

pub fn from_server_config(server: &ServerConfig) -> Result<Self>

Create a connection provider from a server configuration

This avoids unnecessary cloning of individual fields.

pub async fn get_pooled_connection(&self) -> Result<Object<TcpManager>>

Get a connection from the pool (automatically returned when dropped)

pub fn max_size(&self) -> usize

Get the maximum pool size

pub async fn get_health_check_metrics(&self) -> HealthCheckMetrics

Get a snapshot of the current health check metrics

pub fn shutdown(&self)

Gracefully shutdown the periodic health check task

This sends a shutdown signal to the background health check task. The task will complete its current cycle and then terminate.

pub async fn graceful_shutdown(&self)

Gracefully shutdown the pool