pub trait AsyncStream:
AsyncRead
+ AsyncWrite
+ Unpin
+ Send { }Expand description
Trait for async streams that can be used for NNTP connections
This trait is automatically implemented for any type that implements
AsyncRead + AsyncWrite + Unpin + Send, making it easy to support
different connection types (TCP, TLS, etc.).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".